@@ -61,15 +61,17 @@ class Container(Base):
         """
         # 启动ControllerMapping()对象的初始化程序
         self.mapping.init(setting)
-        pprint("'controller' loading completed")
+        pprint("controller loading completed\n" + "----------"*3)
 
         # 初始化拦截队列
         self.reject = setting.container_reject
+        pprint("reject_list loading completed\n" + "----------"*3)
 
         # 初始化资源文件
         self.resource.init(setting)
         for path in self.resource.res_path:
             self.mapping.add(path, self.resource.get_resource, 'all')
+        pprint("resource loading completed\n" + "----------"*3)
 
     def init_filter(self, setting: Setting):
         """
@@ -86,7 +88,7 @@ class Container(Base):
         path_list = list(set(path_list))
         # 将path列表作为参数传递给FilterChain()的init函数，完成filer的初始化
         self.filter.init(setting, path_list)
-        pprint("'filter' loading completed")
+        pprint("filter loading completed\n" + "----------"*3)
 
     def init(self, setting: Setting):
         """
@@ -783,11 +785,15 @@ class Resource(Base):
         """
         for file in Setting.container_resources:
             if os.path.isdir(file):
+                pprint("'{}' folder scanning completed".format(file))
                 for name in Resource.get_all_files(file):
                     path = name[name.find('/'):]
                     if path.find("/index.") >= 0:
                         self.res_path.update({'/': name})
                     self.res_path.update({path: name})
+            else:
+                if file != 'resource':
+                    pprint("'{}' folder not found or it is not a folder".format(file), color='red')
 
     def get_resource(self, request: HttpRequest) -> HttpResponse:
         """
@@ -823,14 +829,14 @@ class Resource(Base):
     def get_resource_response(file_path: str) -> HttpResponse:
         """
         将资源文件打包为Response对象
+        -----------------------------------
+        0.4.0
+        现在他创建response对象时会直接将Resource.file_iterator返回的生成器做为data的参数
+        -----------------------------------
         :param file_path:
         :return:
         """
-        file_data = b""
-        for data in Resource.file_iterator(file_path):
-            file_data += data
-
-        response = HttpResponse(file_data)
+        response = HttpResponse(Resource.file_iterator(file_path))
 
         file_paths = file_path.split('/')
         index = file_paths[-1].rfind('.')
