@@ -30,16 +30,13 @@ ver = {"container_controller": "list",
        "container_reject": "list",
        "server_host": "str",
        "server_port": "int",
-       "server_monitor": "int",
-       "server_requesters": "int",
        "server_workers": "int",
        "server_waiters": "int",
+       "server_process": "bool",
        "log_path": "str",
        "log_max": "int"}
 
 ver_int = {"server_port",
-           "server_monitor",
-           "server_requesters",
            "server_workers",
            "server_waiters",
            "log_max"}
@@ -49,6 +46,8 @@ ver_list = {"container_controller",
             "container_reject",
             "container_resources"}
 
+ver_bool = {"server_process"}
+
 
 class Setting:
     """
@@ -65,10 +64,9 @@ class Setting:
         container_reject(list): 拦截队列
         server_host(str): 主机号
         server_port(int): 端口号
-        server_monitor(int): 监听者数量
-        server_requesters(int): 请求队列长度
         server_workers(int): 工作内核数量
         server_waiters(int): 等待队列长度
+        server_process(bool): 是否开启多进程
         log_path(str): 日志保存地址
         log_max(int): 日志最大长度
     """
@@ -79,10 +77,9 @@ class Setting:
     container_resources = ['resource']
     server_host = "0.0.0.0"
     server_port = 8089
-    server_monitor = 100
-    server_requesters = 1000
-    server_workers = 1000
-    server_waiters = 1000
+    server_workers = 1
+    server_waiters = 1
+    server_process = False
     log_path = "log.txt"
     log_max = 1000
 
@@ -104,10 +101,9 @@ class Setting:
 
         self.server_host = "0.0.0.0"
         self.server_port = 8089
-        self.server_monitor = 100
-        self.server_requesters = 1000
-        self.server_workers = 1000
-        self.server_waiters = 1000
+        self.server_workers = 1
+        self.server_waiters = 1
+        self.server_process = False
 
         self.log_path = "log.txt"
         self.log_max = 1000
@@ -147,6 +143,8 @@ class Setting:
     def __set_data(self, val, data):
         if val in ver_int:
             data = int(data)
+        if val in ver_bool:
+            data = eval(data)
         setattr(self, val, data)
 
     def _verification(self):
